@@ -17,7 +17,7 @@
 #define CHANNEL "#lunar-test"
 #define WEBHOOK_PORT 3000
 
-const char *lunabot_version = "0.0.4";
+const char *lunabot_version = "0.0.5";
 
 unsigned int mainloopend;
 int irc_sock;
@@ -25,6 +25,23 @@ char server_ip[16];
 SSL *pSSL;
 #define BUFFER_SIZE 1024
 char buffer[BUFFER_SIZE];
+struct MHD_Daemon *httpdaemon;
+#define NORMAL      "\003"   // default/restore
+#define BLACK       "\00301"
+#define BLUE        "\00302"
+#define GREEN       "\00303"
+#define RED         "\00304"
+#define BROWN       "\00305"
+#define PURPLE      "\00306"
+#define ORANGE      "\00307"
+#define YELLOW      "\00308"
+#define LIGHT_GREEN "\00309"
+#define CYAN        "\00310"
+#define LIGHT_CYAN  "\00311"
+#define LIGHT_BLUE  "\00312"
+#define PINK        "\00313"
+#define GREY        "\00314"
+#define LIGHT_GREY  "\00315"
 
 char *GetIP(char *hostname) {
 	struct addrinfo hints, *res, *p;
@@ -241,7 +258,8 @@ static enum MHD_Result WebhookCallback(void *cls, struct MHD_Connection *connect
 					if (json_is_string(title) && json_is_string(user) && json_is_string(url)) {
 						char message[512];
 						snprintf(message, sizeof(message), 
-								 "New PR: '%s' from %s - %s", 
+								 "[%sNew PR%s]: '%s' from %s - %s",
+								 GREEN, NORMAL,
 								 json_string_value(title), 
 								 json_string_value(user), 
 								 json_string_value(url));
@@ -255,7 +273,8 @@ static enum MHD_Result WebhookCallback(void *cls, struct MHD_Connection *connect
 					if (json_is_string(title) && json_is_string(user) && json_is_string(url)) {
 						char message[512];
 						snprintf(message, sizeof(message),
-							"Closed PR: '%s' from %s - %s",
+							"[%sClosed PR%s]: '%s' from %s - %s",
+							RED, NORMAL,
 							json_string_value(title),
 							json_string_value(user),
 							json_string_value(url));
@@ -283,42 +302,27 @@ static enum MHD_Result WebhookCallback(void *cls, struct MHD_Connection *connect
 }
 
 // Webhook server thread
-void *WebhookServerStart(void *arg) {
-	struct MHD_Daemon *daemon;
-	daemon = MHD_start_daemon(MHD_USE_SELECT_INTERNALLY, WEBHOOK_PORT, NULL, NULL,
+void WebhookServerStart(void) {
+	httpdaemon = MHD_start_daemon(MHD_USE_SELECT_INTERNALLY, WEBHOOK_PORT, NULL, NULL,
 							  &WebhookCallback, NULL, MHD_OPTION_END);
-	if (!daemon) {
+	if (!httpdaemon) {
 		fprintf(stderr, "lunabot::WebhookServerStart(): Failed to start HTTP server\n");
 		exit(1);
 	}
-
-	fprintf(stderr, "!!Webhook server running on port %d!!\n", WEBHOOK_PORT);
-
-	while (!mainloopend)
-		sleep(5);
-
-	MHD_stop_daemon(daemon);
-	return NULL;
+	else
+		fprintf(stderr, "!!Webhook server running on port %d!!\n", WEBHOOK_PORT);
 }
 
 // Program entry point
 int main() {
-	pthread_t irc_thread, webhook_thread;
-	pthread_attr_t attr;
+	WebhookServerStart();
 
+	pthread_t irc_thread;
+	pthread_attr_t attr;
 	pthread_attr_init(&attr);
 	pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
-
-	// Start the IRC bot
 	pthread_create(&irc_thread, &attr, IrcConnect, NULL);
-
-	// Start the webhook server
-	pthread_create(&webhook_thread, &attr, WebhookServerStart, NULL);
-
-	// Wait for threads to finish
 	pthread_detach(irc_thread);
-	pthread_detach(webhook_thread);
-
 	pthread_attr_destroy(&attr);
 
 	// Start reading user input from the terminal and process per-line
@@ -343,6 +347,7 @@ int main() {
 		}
 	}
 
+	MHD_stop_daemon(httpdaemon);
 	return 0;
 }
 
